allow_subclass

Function allow_subclass 

pub fn allow_subclass() -> SubclassToken
A token that allows the next lock acquisition of the same level as the currently maximal held lock to use an incremented subclass. Allows subclassing of the currently maximal held lock.