pub fn assert_lock_level<L: LockLevel>() -> LockLevelTokenExpand description
Asserts that the current thread can acquire locks at level L.
Returns a token that, when held, forces subsequent locks to be after L.
pub fn assert_lock_level<L: LockLevel>() -> LockLevelTokenAsserts that the current thread can acquire locks at level L.
Returns a token that, when held, forces subsequent locks to be after L.