pub fn ordered_write_lock_vec<'a, R: RwLockLike>(
rwlocks: &[&'a R],
) -> Vec<R::WriteGuard<'a>>Expand description
Acquires multiple rwlocks in a consistent order based on their memory addresses for writing.
pub fn ordered_write_lock_vec<'a, R: RwLockLike>(
rwlocks: &[&'a R],
) -> Vec<R::WriteGuard<'a>>Acquires multiple rwlocks in a consistent order based on their memory addresses for writing.