CondVar

Struct CondVar 

pub struct CondVar { /* private fields */ }
A Condition Variable that is compatible with both standard Mutex and LockDepMutex in Starnix.

Implementations

Source

impl CondVar

pub const fn new() -> Self

pub fn wait<'a, T: 'a, G: WaitableMutexGuard<'a, T>>(&self, guard: &mut G)

Blocks the current thread until this condition variable receives a notification.

pub fn notify_one(&self)

Wakes up one blocked thread on this condvar.

pub fn notify_all(&self)

Wakes up all blocked threads on this condvar.