pub struct DynamicLockDepRwLock<T> { /* private fields */ }Expand description
An RwLock that dynamically enforces lock ordering at runtime, without using types for levels.
Implementations
Sourceimpl<T> DynamicLockDepRwLock<T>
impl<T> DynamicLockDepRwLock<T>
pub const fn new<L: LockLevel>(value: T) -> Self
pub fn read(&self) -> LockDepReadGuard<'_, T>
pub fn write(&self) -> LockDepWriteGuard<'_, T>
Sourcepub fn get_mut(&mut self) -> &mut T
pub fn get_mut(&mut self) -> &mut T
Returns a mutable reference to the underlying data.
Since this call borrows the DynamicLockDepRwLock mutably, no actual locking takes place – the
borrow checker statically ensures no other threads have access to the DynamicLockDepRwLock.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consumes the DynamicLockDepRwLock, returning the underlying data.