pub struct EventWaitGuard<'a> { /* private fields */ }Expand description
A guard object to enforce that clients call begin_wait before block_until.
Implementations
Sourceimpl<'a> EventWaitGuard<'a>
impl<'a> EventWaitGuard<'a>
Sourcepub fn event(&self) -> &'a Arc<InterruptibleEvent>
pub fn event(&self) -> &'a Arc<InterruptibleEvent>
The underlying event associated with this guard.
Sourcepub fn block_until(
self,
new_owner: Option<&Thread>,
deadline: MonotonicInstant,
) -> Result<(), WakeReason>
pub fn block_until( self, new_owner: Option<&Thread>, deadline: MonotonicInstant, ) -> Result<(), WakeReason>
Block the thread until either deadline expires, the event is notified, or the event is
interrupted.