pub struct LockDepMutex<T, L> { /* private fields */ }Expand description
A Mutex that dynamically enforces lock ordering at runtime using types for levels.
Implementations
Sourceimpl<T, L: LockLevel> LockDepMutex<T, L>
impl<T, L: LockLevel> LockDepMutex<T, L>
pub const fn new(value: T) -> Self
pub fn lock(&self) -> LockDepGuard<'_, T>
pub fn try_lock(&self) -> Option<LockDepGuard<'_, T>>
Sourcepub fn get_mut(&mut self) -> &mut T
pub fn get_mut(&mut self) -> &mut T
Returns a mutable reference to the underlying data.
Since this call borrows the LockDepMutex mutably, no actual locking takes place – the
borrow checker statically ensures no other threads have access to the LockDepMutex.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consumes the LockDepMutex, returning the underlying data.