PortEvent

Struct PortEvent 

pub struct PortEvent { /* private fields */ }
A wrapper around a zx::Port that optimizes for the case where events are signaled within a process.

This object will prefer to use a Futex for notifications/interrupts but will fallback to a zx::Port when the port is subscribed for events on an object with [PortEvent.object_wait_async].

Note that the PortEvent does not provide any synchronization between a notifier (caller of [PortEvent.notify]) and a notifiee/waiter (caller of [PortEvent.wait].

Implementations

Source

impl PortEvent

pub fn new() -> Self

Returns a new PortEvent.

pub fn wait(&self, deadline: MonotonicInstant) -> PortWaitResult

Wait for an event to occur, or the deadline has been reached.

pub fn object_wait_async( &self, handle: &dyn AsHandleRef, key: u64, signals: Signals, opts: WaitAsyncOpts, ) -> Result<(), Status>

Subscribe for signals on an object.

pub fn cancel(&self, key: u64)

Cancels async port notifications on an object.

pub fn notify(&self, kind: NotifyKind)

Marks the port as ready to handle a notification (or an interrupt) and wakes up any blocked waiters.