Unlocked

Enum Unlocked 

pub enum Unlocked {}
“Highest” lock level

The lock level for the thing returned by Locked::new. Users of this crate should implement LockAfter<Unlocked> for the root of any lock ordering trees.

Implementations

Source

impl Unlocked

pub unsafe fn new() -> &'static mut Locked<Unlocked>

Entry point for locked access.

Unlocked is the “root” lock level and can be acquired before any lock.

Safety

Unlocked should only be used before any lock in the program has been acquired.

pub unsafe fn new_instance() -> Locked<Unlocked>

Entry point for locked access.

Unlocked is the “root” lock level and can be acquired before any lock.

Safety

Unlocked should only be used before any lock in the program has been acquired.