assert_lock_level

Function assert_lock_level 

pub fn assert_lock_level<L: LockLevel>() -> LockLevelToken<L>
Asserts that the current thread can acquire locks at level L. Returns a token that, when held, forces subsequent locks to be after L.