pub struct CondVar { /* private fields */ }Expand description
A Condition Variable that is compatible with both standard Mutex and LockDepMutex in Starnix.
Implementations
Sourceimpl CondVar
impl CondVar
pub const fn new() -> Self
Sourcepub fn wait<'a, T: 'a, G: WaitableMutexGuard<'a, T>>(&self, guard: &mut G)
pub fn wait<'a, T: 'a, G: WaitableMutexGuard<'a, T>>(&self, guard: &mut G)
Blocks the current thread until this condition variable receives a notification.
Sourcepub fn notify_one(&self)
pub fn notify_one(&self)
Wakes up one blocked thread on this condvar.
Sourcepub fn notify_all(&self)
pub fn notify_all(&self)
Wakes up all blocked threads on this condvar.