pub struct RwSeqLockGuard<'a, G> { /* private fields */ }Expand description
A guard that manages the sequence counter and wraps the underlying lock guard.
When this guard is dropped, the sequence counter is incremented, signaling to readers that the write operation has finished.