WaitToken

Struct WaitToken 

pub struct WaitToken(/* private fields */);
A token that proves the caller is allowed to access the inner guard. Its field is private, so it can only be constructed within this crate.